function [status] = EoBP_plotSDD21 (f, s21, pTitle);

% EoBP_plotSDD21:
% ---------------
% Revision: R1.0
% Date:     19-Nov-2004
% Author:   Howawrd Baumer
% Function: Plot SDD21 versus p802.3ap EoBP informal limit lines
%
% Outputs:
% -------
%   none
%
% Inputs:
% ------
%   f      = list of frequency points (Hz)
%   s21    = list of loss points (complex)
%   pTitle = Title of plot (optional)
%
% Call:
% -----
%   [status] = EoBP_plotSDD21 (f, s21, pTitle);

F0  = 100e6;     % lowest frequency of limit line
F1  = 1e9;       % start frequency of evelope limit lines
F2  = 1.5*5E9;   % lower bound envelope limit line reflection point
dG1 = 3;         % loss envelope at F1 (LSQ fit +/- dG1/2, in dB)
dG2 = 6;         % loss envelope at F2 (LSQ fit +/- dG1/2, in dB)
sG3 = -50/10e9;  % slope of lower bound envelope line above F2 (dB/Hz)
xG4 = -50;       % largest loss of concern, any points outside of F1-F2 
                 % and below this value are don't care

% convert Real-Imaginary to log-Magnitude
mag = 20*log10(abs(s21));

warning off;
% create lower bound limit line for fitted line
SDD21 = 20*log10(abs(EoBPthru(f)));

% truncate responses such that limit line stops at -50dB
iF0   = min(find(f>=F0));
iF3   = min(find(SDD21<-50));
f     = f(iF0:iF3);
mag   = mag(iF0:iF3);
SDD21 = SDD21(iF0:iF3);

% create indexes for frequency points
iF0   = min(find(f>=F0));
iF1   = min(find(f>=F1));
iF2   = min(find(f>=F2));

% fit line to log-lin of s21 from F1 to F2
[X] = polyfit(f(iF1:iF2),mag(iF1:iF2),1);
fit = X(2) + X(1)*f(iF1:iF2);

% create upper bound limit line
um  = ((fit(end)+dG2/2)-(fit(1)+dG1/2)) / (f(iF2)-f(iF1));
UB  = (fit(1)+dG1/2-um*f(iF1)) + um*f(iF1:end);

% create lower bound limit line
lm  = ((fit(end)-dG2/2)-(fit(1)-dG1/2)) / (f(iF2)-f(iF1));
LB1 = (fit(1)-dG1/2-lm*f(iF1)) + lm*f(iF1:iF2);
LB2 = (LB1(end)-sG3*f(iF2+1)) + sG3*f(iF2+1:end);
warning on;

% compare s21 to upper bound
cUB  = mag(iF1:end) > UB;
fpts = f(iF1-1+find(cUB==1));
fmag = mag(iF1-1+find(cUB==1));

% compare s21 to lower bound
cLB  = (mag(iF1:end) < [LB1;LB2]) & (mag(iF1:end)>[-inf*ones(iF2-iF1+1,1);xG4*ones(length(mag)-iF2,1)]);
fpts = [fpts;f(iF1-1+find(cLB))];
fmag = [fmag;mag(iF1-1+find(cLB))];

% compare fit to limit line
cfit = [mag(iF0:iF1-1);fit] < SDD21(iF0:iF2);
fpts = [fpts;f(find(cfit))];
fmag = [fmag;mag(find(cfit))];

% Calculate linear error to fit
elin = 10.^(fit/20) - 10.^(mag(iF1:iF2)/20);
[sum(elin),sqrt(mean(elin.^2)),10*log10(sum(10.^(fit/10)) / sum(elin.^2))];

% Calculate log error to fit
elog = fit - mag(iF1:iF2);
[sum(elog),sqrt(mean(elog.^2))];


fhnl = figure;
plot(f(iF1:end),UB,'k');grid on;hold on
plot(f(iF1:end),[LB1;LB2],'k');
plot(f,SDD21,'r');
plot([f(1),f(end)],[xG4,xG4],'g');
plot(f,mag);
plot(f(iF1:iF2),fit,'m');
plot(fpts,fmag,'r.');

ax = axis;
axis([f(1) f(end) ax(3:4)]);
warning off;
if (nargin>2) title(pTitle); end
warning on;
xlabel('Frequency (Hz)');
ylabel('Loss (dB)');
legend('Upper Bound','Lower Bound','Limit Line','Largest Loss',...
   'Channel','Least Squares Fit','Failing Points',3);
