function [sdd11, sdd12, sdd21, sdd22] = EoBPthru (f);
% EoBPthru:
% ---------
% Revision: R1.0
% Date:     19-Nov-2004
% Author:   Howawrd Baumer
% Function: Generates p802.3ap EoBP SDD21 & SDD11 limit lines
%
% Outputs (Complex):
% ------------------
%   sdd11 = c1 + c2*log10(fx/c3)
%   sdd12 = -20*log10(exp(1))*(b1*fx.^0.5 + b2*fx + b3*fx.^2 - b4*fx.^3);
%   sdd21 = -20*log10(exp(1))*(b1*fx.^0.5 + b2*fx + b3*fx.^2 - b4*fx.^3);
%   sdd22 = c1 + c2*log10(fx/c3)
%            where: b1 = 2.25e-5; b2 = 1.20e-10; b3 = 3.50e-20; b4 = 1.25e-30;
%                   c1 = -22.35;  c2 = 17.19;    c3 = 100e6;
%
% Inputs:
% -------
%   f     = list of frequency points (Hz)
%
% Call:
% -----
%   [sdd11, sdd12, sdd21, sdd22] = EoBPthru (f);
%   or
%   [sdd21] = EoBPthru (f);

% SDD21 parameters
b1 = 2.25e-5;
b2 = 1.20e-10;
b3 = 3.50e-20;
b4 = 1.25e-30;
% SDD11 parameters
c1 = -22.35;
c2 = 17.19;
c3 = 100e6;

[r,c] = size(f);
if (c>1) f=f.'; end
if (f(1)>0) fx = [0;f]; else fx = f; end
fx = f;
[r,c] = size(fx);

% return loss calculations
s11dB = c1 + c2*log10(fx/c3);
s11dB(find(f>=400e6)) = -12;
s11m  = 10.^(s11dB/20);

Tdly    = - 1 / (3e8 * 1.7644);
s11p    = 0 + (2 .* pi .* Tdly .* fx);

[x,y]   = pol2cart(s11p,s11m);
s11     = x + i*y;

% Thru calculations
s21dB = -20*log10(exp(1))*(b1*fx.^0.5 + b2*fx + b3*fx.^2 - b4*fx.^3);
s21m  = 10.^(s21dB/20);

Tdly    = 186e-12 * 40; % 40" fr4 backplane delay 
s21p    = 0 + (2 .* pi .* Tdly .* fx);

[x,y]   = pol2cart(s21p,s21m);
s21     = x + i*y;

if (nargout==1)
   sdd11 = s21;
else
   sdd11 = s11;
   sdd12 = s21;
   sdd21 = s21;
   sdd22 = s11;
end
